@@ -1,16 +1,17 @@
 import inspect
 import typing
 
-import synchronicity
-from synchronicity import Interface, async_wrap
+from synchronicity import async_wrap
 from synchronicity.async_wrap import wraps_by_interface
+from synchronicity.interface import Interface
+from synchronicity.synchronizer import FunctionWithAio
 
 
 def test_wrap_corofunc_using_async():
     async def foo():
         pass
 
-    @wraps_by_interface(Interface.ASYNC, foo)
+    @wraps_by_interface(Interface._ASYNC_WITH_BLOCKING_TYPES, foo)
     async def bar():
         pass
 
@@ -21,7 +22,7 @@ def test_wrap_corofunc_using_non_async():
     async def foo():
         pass
 
-    @wraps_by_interface(Interface.ASYNC, foo)
+    @wraps_by_interface(Interface._ASYNC_WITH_BLOCKING_TYPES, foo)
     def bar():
         pass
 
@@ -30,13 +31,12 @@ def test_wrap_corofunc_using_non_async():
 
 def test_wrap_asynccontextmanager_annotations():
     @async_wrap.asynccontextmanager  # this would not work with contextlib.asynccontextmanager
-    async def foo() -> typing.AsyncGenerator[int, None]:
-        pass
+    async def foo() -> typing.AsyncGenerator[int, None]: ...
 
     assert foo.__annotations__["return"] == typing.AsyncContextManager[int]
 
 
-def test_wrap_staticmethod():
+def test_wrap_staticmethod(synchronizer):
     class Foo:
         @staticmethod
         async def a_static_method() -> typing.Awaitable[str]:
@@ -45,14 +45,8 @@ def test_wrap_staticmethod():
 
             return wrapped()
 
-    synchronizer = synchronicity.Synchronizer()
     BlockingFoo = synchronizer.create_blocking(Foo)
-    AsyncFoo = synchronizer.create_async(Foo)
 
-    assert isinstance(BlockingFoo.__dict__["a_static_method"], staticmethod)
-    assert isinstance(AsyncFoo.__dict__["a_static_method"], staticmethod)
-
-    assert inspect.iscoroutinefunction(AsyncFoo.__dict__["a_static_method"].__func__)
-    assert not inspect.iscoroutinefunction(
-        BlockingFoo.__dict__["a_static_method"].__func__
-    )
+    assert isinstance(BlockingFoo.__dict__["a_static_method"], FunctionWithAio)
+    assert not inspect.iscoroutinefunction(BlockingFoo.__dict__["a_static_method"]._func)
+    assert inspect.iscoroutinefunction(BlockingFoo.__dict__["a_static_method"].aio)
