@@ -2,8 +2,6 @@ import asyncio
 import pytest
 import time
 
-from synchronicity import Interface, Synchronizer
-
 
 def sleep(ms):
     time.sleep(ms / 1000)
@@ -16,31 +14,27 @@ async def sleep_async(ms):
 
 
 @pytest.mark.asyncio
-async def test_blocking():
-    s = Synchronizer()
-    sleep_cb = s.create_callback(sleep, Interface.BLOCKING)
+async def test_blocking(synchronizer):
+    sleep_cb = synchronizer.create_callback(sleep)
     t0 = time.time()
-    coros = [sleep_cb(200), sleep_cb(300)]
+    coros = [sleep_cb(200), sleep_cb(300), sleep_cb(300), sleep_cb(300)]
     rets = await asyncio.gather(*coros)
-    assert rets == [200, 300]
-    assert 0.3 <= time.time() - t0 <= 0.4  # make sure they run in parallel
+    assert rets == [200, 300, 300, 300]
+    assert 0.3 <= time.time() - t0 < 0.5  # make sure they run in parallel
 
 
 @pytest.mark.asyncio
-async def test_async():
-    s = Synchronizer()
-    sleep_cb = s.create_callback(sleep_async, Interface.ASYNC)
+async def test_async(synchronizer):
+    sleep_cb = synchronizer.create_callback(sleep_async)
     t0 = time.time()
-    coros = [sleep_cb(200), sleep_cb(300)]
+    coros = [sleep_cb(200), sleep_cb(300), sleep_cb(300), sleep_cb(300)]
     rets = await asyncio.gather(*coros)
-    assert rets == [200, 300]
-    assert 0.3 <= time.time() - t0 <= 0.4
+    assert rets == [200, 300, 300, 300]
+    assert 0.3 <= time.time() - t0 <= 0.5
 
 
 @pytest.mark.asyncio
-async def test_translate():
-    s = Synchronizer()
-
+async def test_translate(synchronizer):
     class Foo:
         def __init__(self, x):
             self.x = x
@@ -48,14 +42,14 @@ async def test_translate():
         def get(self):
             return self.x
 
-    BlockingFoo = s.create_blocking(Foo)
+    BlockingFoo = synchronizer.create_blocking(Foo)
 
     def f(foo):
         assert isinstance(foo, BlockingFoo)
         x = foo.get()
         return BlockingFoo(x + 1)
 
-    f_cb = s.create_callback(f, Interface.BLOCKING)
+    f_cb = synchronizer.create_callback(f)
 
     foo1 = Foo(42)
     foo2 = await f_cb(foo1)
