@@ -1,13 +1,12 @@
 import asyncio
 import pytest
-from typing import Dict, Any
+from typing import Any, Dict
 
-from synchronicity import Synchronizer
+from synchronicity import classproperty
 
 
-def test_getattr():
-    s = Synchronizer()
-
+@pytest.mark.asyncio
+async def test_getattr(synchronizer):
     class Foo:
         _attrs: Dict[str, Any]
 
@@ -33,27 +32,38 @@ def test_getattr():
         def make_foo():
             return Foo()
 
+        @classproperty
+        def my_cls_prop(cls):
+            return "abc"
+
+        @classproperty
+        async def another_cls_prop(cls):
+            await asyncio.sleep(0.01)
+            return "another-cls-prop"
+
     foo = Foo()
     foo.x = 42
-    assert asyncio.run(foo.x) == 42
+    assert await foo.x == 42
     with pytest.raises(KeyError):
-        asyncio.run(foo.y)
+        await foo.y
     assert foo.z == 42
+    assert Foo.my_cls_prop == "abc"
+    assert await Foo.another_cls_prop == "another-cls-prop"
 
-    BlockingFoo = s.create_blocking(Foo)
+    BlockingFoo = synchronizer.create_blocking(Foo)
 
     blocking_foo = BlockingFoo()
-    blocking_foo.x = 42
-    assert blocking_foo.x == 42
+    blocking_foo.x = 43
+    assert blocking_foo.x == 43
     with pytest.raises(KeyError):
         blocking_foo.y
-    assert blocking_foo.z == 42
+    assert blocking_foo.z == 43
+    assert BlockingFoo.my_cls_prop == "abc"
+    assert BlockingFoo.another_cls_prop == "another-cls-prop"
 
     blocking_foo = BlockingFoo.make_foo()
+    blocking_foo.x = 44
     assert isinstance(blocking_foo, BlockingFoo)
 
-    AsyncFoo = s.create_async(Foo)
-    async_foo = AsyncFoo()
-    async_foo.x = 42
-    assert asyncio.run(async_foo.x) == 42
-    assert async_foo.z == 42
+    # TODO: there is no longer a way to make async properties, but there is this w/ async __getattr__:
+    assert await blocking_foo.__getattr__.aio("x") == 44
